<?php
/**
 * Comments Template
 *
 * Displays comments and comments form
 *
 * @package      responsive_mobile
 * @license      license.txt
 * @copyright    2014 CyberChimps Inc
 * @since        0.0.1
 *
 * Please do not edit this file. This file is part of the responsive_mobile Framework and all modifications
 * should be made in a child theme.
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	?><p class="nocomments"><?php _e( 'This post is password protected. Enter the password to view any comments.', 'responsive-mobile' ); ?></p><?php
	return;
}
?>

<div id="comments" class="comments-area">

	<?php if ( have_comments() ) : ?>
		<h2 class="comments-title">
			<?php
				printf( _nx( 'One comment on &ldquo;%2$s&rdquo;', '%1$s comments on &ldquo;%2$s&rdquo;', get_comments_number(), 'comments title', 'responsive-mobile' ),
					number_format_i18n( get_comments_number() ), '<span>' . get_the_title() . '</span>' );
			?>
		</h2>

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : ?>
		<nav id="comment-nav-above" class="comment-navigation navigation" role="navigation">
			<h1 class="screen-reader-text"><?php _e( 'Comment navigation', 'responsive-mobile' ); ?></h1>
			<div class="nav-previous previous"><?php previous_comments_link( __( '&larr; Older Comments', 'responsive-mobile' ) ); ?></div>
			<div class="nav-next next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'responsive-mobile' ) ); ?></div>
		</nav><!-- #comment-nav-above -->
		<?php endif; ?>

		<ol class="commentlist">
			<?php
				wp_list_comments( array(
					'avatar_size' => '60',
					'type'        => 'comment'
				) );
			?>
		</ol><!-- .comment-list -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
		<nav id="comment-nav-below" class="comment-navigation navigation" role="navigation">
			<h1 class="screen-reader-text"><?php _e( 'Comment navigation', 'responsive-mobile' ); ?></h1>
			<div class="nav-previous previous"><?php previous_comments_link( __( '&larr; Older Comments', 'responsive-mobile' ) ); ?></div>
			<div class="nav-next next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'responsive-mobile' ) ); ?></div>
		</nav><!-- #comment-nav-below -->
		<?php endif; // check for comment navigation ?>

	<?php endif; // have_comments() ?>

	<?php
		// If comments are closed and there are comments, let's leave a little note, shall we?
		if ( ! comments_open() && '0' != get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
	?>
		<p class="no-comments"><?php _e( 'Comments are closed.', 'responsive-mobile' ); ?></p>
	<?php endif; ?>

	<?php
	if( ! empty( $comments_by_type['pings'] ) ) : // let's seperate pings/trackbacks from comments
		$count = count( $comments_by_type['pings'] );
		( $count !== 1 ) ? $txt = __( 'Pings&#47;Trackbacks', 'responsive-mobile' ) : $txt = __( 'Pings&#47;Trackbacks', 'responsive-mobile' );
		?>

		<h2 id="pings"><?php printf( __( '%1$d %2$s for "%3$s"', 'responsive-mobile' ), $count, $txt, get_the_title() ) ?></h2>

		<ol class="commentlist">
			<?php wp_list_comments( array(
					'max_depth' => '<em>',
					'type'      => 'pings'
				) ); ?>
		</ol>

	<?php endif; ?>

	<?php if( comments_open() ) : ?>

		<?php
		$fields = array(
			'author' => '<p class="comment-form-author">' . '<label for="author">' . __( 'Name', 'responsive-mobile' ) . '</label> ' . ( $req ? '<span class="required">*</span>' : '' ) .
			'<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" /></p>',
			'email'  => '<p class="comment-form-email"><label for="email">' . __( 'E-mail', 'responsive-mobile' ) . '</label> ' . ( $req ? '<span class="required">*</span>' : '' ) .
			'<input id="email" name="email" type="text" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30" /></p>',
			'url'    => '<p class="comment-form-url"><label for="url">' . __( 'Website', 'responsive-mobile' ) . '</label>' .
			'<input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>',
		);

		comment_form();
		?>

	<?php endif; ?>

</div><!-- #comments -->
